@@ -57,7 +57,8 @@ class Tools(object):
             "date": "str",
             "object": "dict",
             "password": "str",
-            "integer": "int"
+            "integer": "int",
+            "file": "dict"
         }
 
         if isinstance(enm, list):
